==> homesitemaker-v0.4.5.tar.gz: homesitemaker/includes/languages/english/homesite-includes-dbwa.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/
	

//---------- ./homesite/includes/dbwa.php ----------

$TEXT001="The selected nickname already exists!!!<br>".
         "Please choose a new one";

$TEXT002="The given passwords doesn't match";

$TEXT003="The pasword needs to have more than 8 characters and less than 16.";

$TEXT004="The Nickname can not have more than 16 characters.<br>".
         "Please choose a new one.";

$TEXT005="Try Again !";
$TEXT006="The Title field is required.";
$TEXT007="In you choose:<p><i>List of selected users only</i></p>".
         "Then, you need to choose almost one user from the list.";

$TEXT008="You can not select a list of selected users<br>".
         "whitout choose <i>List of selected users only </i>option";

$TEXT009="The selected album has been deleted.";
$TEXT010="size";
$TEXT011="has been deleted";
$TEXT012="The";
$TEXT013="folder has been deleted";
$TEXT014="All the database entries for this info has been deleted";

$TEXT015="Your new has been stored.".
         "If everything is correct, it will be published by one of our editors as soon as posible.";

$TEXT016="User was sucessfully created. Now you can login as a registered user";
$TEXT017="Your request has been processed";

$TEXT018="Invalid User! You can't perform this operation.<br>".
         "Maybe you shouldn't stay here!!!<br>".
         "This attepmt has been reported to the site admin";
$TEXT019="Feeds RSS 2.0 has been updated !";
$TEXT020="replaced with ->";

$SUBMIT_NEW="Submit";     // IMPORTANT !! Put the same string you putted $TEXT001 in homesite-news 
$SAVE="Save";             // IMPORTANT !! Put the same string you putted $TEXT023 in homesite-news
$PREVIEW="Preview";       // IMPORTANT !! Put the same string you putted $TEXT025 in homesite-news
$PUBLISH="Publish";       // IMPORTANT !! Put the same string you putted $TEXT026 and $IEBM002 like 
                          // in homesite-news and homesite-info 
?>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/includes/languages/english/homesite-includes-dbwa.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/
	

//---------- ./homesite/includes/dbwa.php ----------

$TEXT001="The selected nickname already exists!!!<br>".
         "Please choose a new one";

$TEXT002="The given passwords doesn't match";

$TEXT003="The pasword needs to have more than 8 characters and less than 16.";

$TEXT004="The Nickname can not have more than 16 characters.<br>".
         "Please choose a new one.";

$TEXT005="Try Again !";
$TEXT006="The Title field is required.";
$TEXT007="In you choose:<p><i>List of selected users only</i></p>".
         "Then, you need to choose almost one user from the list.";

$TEXT008="You can not select a list of selected users<br>".
         "whitout choose <i>List of selected users only </i>option";

$TEXT009="The selected album has been deleted.";
$TEXT010="size";
$TEXT011="has been deleted";
$TEXT012="The";
$TEXT013="folder has been deleted";
$TEXT014="All the database entries for this info has been deleted";

$TEXT015="Your new has been stored.".
         "If everything is correct, it will be published by one of our editors as soon as posible.";

$TEXT016="User was sucessfully created. Now you can login as a registered user";
$TEXT017="Your request has been processed";

$TEXT018="Invalid User! You can't perform this operation.<br>".
         "Maybe you shouldn't stay here!!!<br>".
         "This attepmt has been reported to the site admin";
$TEXT019="Feeds RSS 2.0 has been updated !";
$TEXT020="replaced with ->";
$TEXT021="ERROR !<br>There is a mismatch between<br>the entered code and the showed one.<br>Please try it again.<br><br>";

$SUBMIT_NEW="Submit";     // IMPORTANT !! Put the same string you putted $TEXT001 in homesite-news 
$SAVE="Save";             // IMPORTANT !! Put the same string you putted $TEXT023 in homesite-news
$PREVIEW="Preview";       // IMPORTANT !! Put the same string you putted $TEXT025 in homesite-news
$PUBLISH="Publish";       // IMPORTANT !! Put the same string you putted $TEXT026 and $IEBM002 like 
                          // in homesite-news and homesite-info 
?>
